<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xmi="http://www.omg.org/XMI"
  xmlns:topology.cell="http://www.ibm.com/websphere/appserver/schemas/5.0/topology.cell.xmi"
  xmlns:topology.cluster="http://www.ibm.com/websphere/appserver/schemas/5.0/topology.cluster.xmi"
  xmlns:pmirm="http://www.ibm.com/websphere/appserver/schemas/5.0/pmirm.xmi"
  xmlns:multibroker="http://www.ibm.com/websphere/appserver/schemas/5.0/multibroker.xmi"
  xmlns:serverindex="http://www.ibm.com/websphere/appserver/schemas/5.0/serverindex.xmi"
  xmlns:AdminHelper="com.ibm.ws.management.AdminHelper"
  xmlns:PlatformHelper="com.ibm.ws.util.PlatformHelper">

<xsl:import href="copy.xsl"/>

<!-- Defect 201550: Do NOT remove shortName and Security 'type' on zOS. 
     Call Java code:
       com.ibm.ws.management.AdminHelper.getPlatformHelper().isZOS()
-->
<xsl:variable name="platformHelper" select="AdminHelper:getPlatformHelper()"/>
<xsl:variable name="isZOS" select="PlatformHelper:isZOS($platformHelper)"/>

<!-- Remove the shortName in the Cell element
     Schema file: topology.cell.xsd
-->
<xsl:template match="topology.cell:Cell/shortName">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>
<xsl:template match="topology.cell:Cell/@shortName">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>

<!-- LI 3436
     Remove boostrapAddresses from foreignCells in the Cell element.  Also, if
     bootstrapAddress (note singular vs. plural) is not set, set bootstrapAddress
     to the first bootstrapAddresses element.
-->

<xsl:template match="topology.cell:Cell/foreignCells/bootstrapAddresses">
    <!-- If bootstrapAddress is not set, invoke the createBootstrapAddress
         template.  Pass in the position of this bootstrapAddresses element to
         the template, along with the host and port.  The template will create
         a bootstrapAddress element only if this slement is the first bootstrapAddresses
         element.  It will use the host and port passed to it.  Note that position()
         is not used to determine the position of this bootstrapAddresses element in
         the node.  This is because position includes all element types to determine 
         the position.  The "number" XSLT element is used because it returns the position
         relative to other elements of the same type.
    -->
    <xsl:if test="not(../bootstrapAddress)">
       <xsl:call-template name="createBootstrapAddress">
          <xsl:with-param name="addrNum"> <xsl:number /> </xsl:with-param>
          <xsl:with-param name="host">    <xsl:value-of select="./@host"/> </xsl:with-param>
          <xsl:with-param name="port">    <xsl:value-of select="./@port"/> </xsl:with-param>
       </xsl:call-template>
    </xsl:if>
</xsl:template>

<!-- This template creates a bootstrapAddress element if the position (addrNum) of the calling
     bootstrapAddresses element is the first in the list of bootstrapAddresses.
-->
<xsl:template name="createBootstrapAddress">
  <xsl:param name="addrNum"/>
  <xsl:param name="host"/>
  <xsl:param name="port"/>
  <xsl:if test="$addrNum=1">
     <xsl:text>&#xa;    </xsl:text>
     <xsl:element name="bootstrapAddress">
        <xsl:attribute name="xmi:id"> <xsl:text>EndPoint_0</xsl:text>   </xsl:attribute>
        <xsl:attribute name="host"><xsl:value-of select="$host"/></xsl:attribute>
        <xsl:attribute name="port"><xsl:value-of select="$port"/></xsl:attribute>
     </xsl:element>
  </xsl:if>
</xsl:template>



<!-- Remove the shortName & uniqueId in the ServerCluster element
     Schema file: topology.cluster.xsd
-->
<xsl:template match="topology.cluster:ServerCluster/shortName">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>
<xsl:template match="topology.cluster:ServerCluster/@shortName">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>

<xsl:template match="topology.cluster:ServerCluster/uniqueId">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>
<xsl:template match="topology.cluster:ServerCluster/@uniqueId">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>

<!-- Remove the enableLog and armType attributes from PMIRequestMatrics
     LI: 2505.9
-->
<xsl:template match="pmirm:PMIRequestMetrics/@enableLog"/>
<xsl:template match="pmirm:PMIRequestMetrics/@armType"/>
<xsl:template match="pmirm:PMIRequestMetrics/@armTransactionFactory"/>
<xsl:template match="pmirm:PMIRequestMetrics/@enabledComponents"/>
<xsl:template match="pmirm:PMIRequestMetrics/@armCallback"/>
<xsl:template match="pmirm:PMIRequestMetrics/@dynamicEnable"/>

<!-- Remove the JMS and WEB_SERVICES filters from pmirm.xml
     Defect: 220619
-->
<xsl:template match="pmirm:PMIRequestMetrics/filters">
  <xsl:if test="not(@type='JMS' or @type='WEB_SERVICES')">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>

<!-- Remove all <enabledComponents> from pmirm.xml
     Defect: 220616
-->
<xsl:template match="pmirm:PMIRequestMetrics/enabledComponents"/>     
<xsl:template match="pmirm:PMIRequestMetrics/instrumentedComponents"/>     

<!-- Remove the numberOfReplicas attribute and the DataReplicationDomain element
     LI: 2430.34
-->
<xsl:template match="multibroker:MultibrokerDomain/defaultDataReplicationSettings/@numberOfReplicas"/>
<xsl:template match="multibroker:DataReplicationDomain">
   <!-- D301867 When filtering out DatareplicationDomain on 64-bit,
       if there is no MultibrokerDomain present, need to 
       introduce a xmi:Documentation. Otherwise, the resulting file
       can not be read by the runtime. -->
   <xsl:choose>
       <xsl:when test="//multibroker:MultibrokerDomain">
       </xsl:when>
       <xsl:otherwise>
          <xmi:XMI>
              <xmi:Documentation>
                 <contact>multibroker:DataReplicationDomain was filtered out.</contact>
              </xmi:Documentation>
           </xmi:XMI>
       </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- Remove nodeGroupName and enableHA from cluster.xml
     LI: 2303.22
-->
<xsl:template match="topology.cluster:ServerCluster/@nodeGroupName"/>
<xsl:template match="topology.cluster:ServerCluster/@enableHA"/>

<!-- Remove recoveryLog element from serverindex.xml
     Defect: 222798
-->
<xsl:template match="serverindex:ServerIndex/serverEntries/recoveryLog"/>

<xsl:template match="serverindex:ServerIndex/serverEntries/@serverShortName">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>
<xsl:template match="serverindex:ServerIndex/serverEntries/@serverUniqueId">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>
<xsl:template match="serverindex:ServerIndex/serverEntries/@genericShortName">
  <xsl:if test="$isZOS">
    <xsl:call-template name="copy"/>
  </xsl:if>
</xsl:template>

<!-- Remove the cellRegistered attribute in the Cell element -->
<xsl:template match="topology.cell:Cell/@cellRegistered"/>

<!-- Remove any adminAgentRegistration element in the Cell element -->
<xsl:template match="topology.cell:Cell/adminAgentRegistration"/>

</xsl:stylesheet>
